@@ -886,7 +886,7 @@ class World:
 
     def setBlock(self, x,y,z, blocktype):
         pos = int(x),int(y),int(z)
-        print("World.setBlock", pos)
+        #print("World.setBlock", pos)
         if blocktype == 'air':
             if pos in self.window.model.world:
                 self.window.model.remove_block(pos)
